@@ -1,13 +1,8 @@
 from asva.restoring_force.RestoringForce import RestoringForce
 
 class Elastic(RestoringForce):
-    def __init__(self, k0):
-        super().__init__()
-        self.k0 = k0
-
-    def step(self, dis: float) -> float:
+    def step(self, dis: float) -> None:
         # init
         self.init_step(dis)
         # end
         self.end_step(self.k0)
-        return self.k0
\ No newline at end of file
