@@ -1,10 +1,8 @@
 from asva.restoring_force.RestoringForce import RestoringForce
 
 class Gyakko(RestoringForce):
-    def __init__(self, k0, a1, a2, f1, f2):
-        super().__init__()
-        self.k0 = k0
-        self.k = self.k0
+    def __init__(self, n1: int, n2: int, k0: float, a1: float, a2: float, f1: float, f2: float):
+        super().__init__(n1, n2, k0)
         self.a1 = a1
         self.a2 = a2
         self.f1 = f1
@@ -12,7 +10,7 @@ class Gyakko(RestoringForce):
         self.disc = self.f1 / self.k0
         self.disy = (self.f2 - (1 - self.a1) * self.f1) / (self.a1 * self.k0)
 
-    def step(self, dis) -> float:
+    def step(self, dis) -> None:
         # init
         self.init_step(dis)
 
@@ -25,4 +23,3 @@ class Gyakko(RestoringForce):
 
         # end
         self.end_step(self.k)
-        return self.k
\ No newline at end of file
